# -*- coding: utf-8 -*-
# Generated by Django 1.11.13 on 2018-12-20 14:46
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='GiropayTransaction',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True, verbose_name='created_at')),
                ('reference', models.TextField(null=True, verbose_name='reference')),
                ('backend_tx_id', models.TextField(null=True, verbose_name='backend tx id')),
                ('merchant_tx_id', models.CharField(max_length=255, unique=True, verbose_name='merchant tx id')),
                ('merchant_id', models.IntegerField(verbose_name='amount in Cents')),
                ('project_id', models.IntegerField(verbose_name='amount in Cents')),
                ('amount', models.PositiveIntegerField(verbose_name='amount in Cents')),
                ('currency', models.CharField(default='EUR', max_length=3, verbose_name='Currency Code (3 Chars)')),
                ('purpose', models.CharField(max_length=27, verbose_name='purpose')),
                ('iban', models.CharField(blank=True, max_length=34, null=True, verbose_name='iban')),
                ('bic', models.CharField(blank=True, max_length=11, null=True, verbose_name='bic')),
                ('redirect_url', models.TextField(verbose_name='redirect url')),
                ('notify_url', models.TextField(verbose_name='notify url')),
                ('external_payment_url', models.TextField(blank=True, null=True, verbose_name='redirect url to users online banking')),
                ('success_url', models.TextField(verbose_name='success url')),
                ('error_url', models.TextField(verbose_name='error url')),
                ('info_1_label', models.CharField(blank=True, max_length=30, null=True, verbose_name='info 1 label')),
                ('info_1_text', models.CharField(blank=True, max_length=80, null=True, verbose_name='info 1 text')),
                ('info_2_label', models.CharField(blank=True, max_length=30, null=True, verbose_name='info 2 label')),
                ('info_2_text', models.CharField(blank=True, max_length=80, null=True, verbose_name='info 2 text')),
                ('info_3_label', models.CharField(blank=True, max_length=30, null=True, verbose_name='info 3 label')),
                ('info_3_text', models.CharField(blank=True, max_length=80, null=True, verbose_name='info 3 text')),
                ('info_4_label', models.CharField(blank=True, max_length=30, null=True, verbose_name='info 4 label')),
                ('info_4_text', models.CharField(blank=True, max_length=80, null=True, verbose_name='info 4 text')),
                ('info_5_label', models.CharField(blank=True, max_length=30, null=True, verbose_name='info 5 label')),
                ('info_5_text', models.CharField(blank=True, max_length=80, null=True, verbose_name='info 5 text')),
                ('result_payment', models.IntegerField(null=True, verbose_name='return code from giropay transaction')),
                ('result_avs', models.IntegerField(blank=True, null=True, verbose_name='return code of giropay age verification')),
                ('obv_name', models.TextField(blank=True, null=True, verbose_name='obv name')),
                ('latest_response_code', models.IntegerField(null=True, verbose_name='rc field from giropay response')),
                ('latest_response_msg', models.TextField(blank=True, null=True, verbose_name='msg field from giropay response')),
            ],
            options={
                'verbose_name': 'Giropay Transaction',
                'verbose_name_plural': 'Giropay Transaction',
            },
        ),
    ]
